Page 127 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 127

Home

    telling us on a day to day basis, most of the countries in
    Eastern Europe are still Stalinistic, with very strong
    armed, repressive regimes. So that while we are hearing
    in the West that the East Block has collapsed, the Cold
    War is over, the Iron Curtain is cracking, and
    democracy, reform, and liberalism are everywhere, this
    of course is not the case.

    is still one of day to day persecution, day to day
    hardship, in effect slavery under a Soviet dominated
    system. And even in the two places where there have
    been some changes, Hungary and Poland, the

    been some changes, Hungary and Poland, the
    Communists control the secret police, the military, and
    the presidencies of those countries,. . .

    and

    Poland,

    the

    some

    The one solution consistently offered by men like
    Anitoliy Golitsyn and Ambassador Funderburk to reverse

    Not only has the foreign policy of the United states
    (under control of the CFR) been geared to raising up and
    maintaining Communist leaders, it has also been aimed
    at destroying anticommunists who have been friendly to
    the United States, especially sincerely religious leaders
    such as the former Chinese leader Chiang Kai-shek.
    Chiang Kai-shek could be described as the George
    Washington of his country, their lives being similar. Both
    were military men, both fought a revolution, both were
    Christians, and each became the head of his country.

    122

    The Secret Side of History

    Contrary to what most of the media in America is

    The norm of existence for people in the East Block

    these conditions, and allow these enslaved nations to free

    themselves, is for the West to end all aid to Communist

    Block nations.